.. _trojanvision.attacks.backdoor.clean_label:

clean_label
================

.. currentmodule:: trojanvision.attacks

.. autoclass:: InvisiblePoison
    :members:

.. autoclass:: Refool
    :members:
